Waelstow
========
    [wel stoʊ]  / *noun* 
    
    1) literal: "death field" or "slaugher field"; 
    2) Anglo Saxon term for battlefields
    3) A collection of python testing utilties

Installation
============

.. code-block:: bash

    $ pip install waelstow

Supports
========

Python wrench has been tested with Python 2.7, 3.5, and 3.6

Docs & Source
=============

Docs: http://python-waelstow.readthedocs.io/en/latest/

Source: https://github.com/cltrudeau/waelstow
